Class: Sourcerer::Sync::Cast::CastResult

Inherits:
Struct
  • Object
show all
Defined in:
lib/sourcerer/sync/cast.rb

Overview

Returned by both sync and init.

Instance Attribute Summary collapse

Instance Attribute Details

#applied_changesObject (readonly)

Tag names whose block content was replaced (empty on a dry run even when differences exist).



22
23
24
25
26
27
28
# File 'lib/sourcerer/sync/cast.rb', line 22

CastResult = Struct.new(
:target_path,
:applied_changes,
:warnings,
:errors,
:diff,
keyword_init: true)

#diffObject (readonly)

Unified diff output when differences were detected (populated on dry runs and when changes were applied).



22
23
24
25
26
27
28
# File 'lib/sourcerer/sync/cast.rb', line 22

CastResult = Struct.new(
:target_path,
:applied_changes,
:warnings,
:errors,
:diff,
keyword_init: true)

#errorsObject (readonly)

Fatal messages; file was not written.



22
23
24
25
26
27
28
# File 'lib/sourcerer/sync/cast.rb', line 22

CastResult = Struct.new(
:target_path,
:applied_changes,
:warnings,
:errors,
:diff,
keyword_init: true)

#target_pathObject (readonly)

Absolute path of the target file.



22
23
24
25
26
27
28
# File 'lib/sourcerer/sync/cast.rb', line 22

CastResult = Struct.new(
:target_path,
:applied_changes,
:warnings,
:errors,
:diff,
keyword_init: true)

#warningsObject (readonly)

Non-fatal diagnostic messages.



22
23
24
25
26
27
28
# File 'lib/sourcerer/sync/cast.rb', line 22

CastResult = Struct.new(
:target_path,
:applied_changes,
:warnings,
:errors,
:diff,
keyword_init: true)