Class: Sourcerer::Sync::Cast::CastResult
- Inherits:
-
Struct
- Object
- Struct
- Sourcerer::Sync::Cast::CastResult
- Defined in:
- lib/sourcerer/sync/cast.rb
Overview
Instance Attribute Summary collapse
-
#applied_changes ⇒ Object
readonly
Tag names whose block content was replaced (empty on a dry run even when differences exist).
-
#diff ⇒ Object
readonly
Unified diff output when differences were detected (populated on dry runs and when changes were applied).
-
#errors ⇒ Object
readonly
Fatal messages; file was not written.
-
#target_path ⇒ Object
readonly
Absolute path of the target file.
-
#warnings ⇒ Object
readonly
Non-fatal diagnostic messages.
Instance Attribute Details
#applied_changes ⇒ Object (readonly)
Tag names whose block content was replaced (empty on a dry run even when differences exist).
22 23 24 25 26 27 28 |
# File 'lib/sourcerer/sync/cast.rb', line 22 CastResult = Struct.new( :target_path, :applied_changes, :warnings, :errors, :diff, keyword_init: true) |
#diff ⇒ Object (readonly)
Unified diff output when differences were detected (populated on dry runs and when changes were applied).
22 23 24 25 26 27 28 |
# File 'lib/sourcerer/sync/cast.rb', line 22 CastResult = Struct.new( :target_path, :applied_changes, :warnings, :errors, :diff, keyword_init: true) |
#errors ⇒ Object (readonly)
Fatal messages; file was not written.
22 23 24 25 26 27 28 |
# File 'lib/sourcerer/sync/cast.rb', line 22 CastResult = Struct.new( :target_path, :applied_changes, :warnings, :errors, :diff, keyword_init: true) |
#target_path ⇒ Object (readonly)
Absolute path of the target file.
22 23 24 25 26 27 28 |
# File 'lib/sourcerer/sync/cast.rb', line 22 CastResult = Struct.new( :target_path, :applied_changes, :warnings, :errors, :diff, keyword_init: true) |
#warnings ⇒ Object (readonly)
Non-fatal diagnostic messages.
22 23 24 25 26 27 28 |
# File 'lib/sourcerer/sync/cast.rb', line 22 CastResult = Struct.new( :target_path, :applied_changes, :warnings, :errors, :diff, keyword_init: true) |